![PyPI - Python Version](https://img.shields.io/pypi/pyversions/saturno)
[![PyPI](https://img.shields.io/pypi/v/saturno?color=red)](https://pypi.org/project/saturno/)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
![GitHub](https://img.shields.io/github/license/mortafix/saturno)

# Setup
You can find the package, [here](https://pypi.org/project/saturno/).
```
pip3 install saturno
saturno manage
```

# Usage
```bash
saturno manage  # add and remove anime, other parameters configuration
saturno run	# download every available episodes
```